@@ -63,7 +63,7 @@ has 'abs_file' => (
     isa      => File,
     lazy     => 1,
     init_arg => undef,
-    default  => sub { $_[0]->file->absolute },
+    default  => sub { $_[0]->file->absolute->resolve },
 );
 
 use overload '""' => '_stringify';
@@ -390,7 +390,9 @@ sub accepted_for_out {
 }
 
 sub delete {
-    $_[0]->file->remove;
+    my $self = shift;
+    $self->file->remove if $self->exists_base_file;
+    $self->_sum_file->delete if $self->sum;
 }
 
 sub rename {
